==> apache-camel-3.18.3-src.zip: apache-camel-3.18.3/core/camel-core-reifier/src/main/java/org/apache/camel/reifier/language/CSimpleExpressionReifier.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.reifier.language;

import org.apache.camel.CamelContext;
import org.apache.camel.Expression;
import org.apache.camel.Predicate;
import org.apache.camel.RuntimeCamelException;
import org.apache.camel.model.language.CSimpleExpression;
import org.apache.camel.model.language.ExpressionDefinition;
import org.apache.camel.spi.Language;

public class CSimpleExpressionReifier extends ExpressionReifier<CSimpleExpression> {

    public CSimpleExpressionReifier(CamelContext camelContext, ExpressionDefinition definition) {
        super(camelContext, (CSimpleExpression) definition);
    }

    @Override
    protected void configureLanguage(Language language) {
        if (definition.getResultType() == null && definition.getResultTypeName() != null) {
            try {
                Class<?> clazz = camelContext.getClassResolver().resolveMandatoryClass(definition.getResultTypeName());
                definition.setResultType(clazz);
            } catch (ClassNotFoundException e) {
                throw RuntimeCamelException.wrapRuntimeException(e);
            }
        }
    }

    private Object[] createProperties() {
        Object[] properties = new Object[1];
        properties[0] = definition.getResultType();
        return properties;
    }

    @Override
    public boolean isResolveOptionalExternalScriptEnabled() {
        // csimple language will handle to resolve external scripts as they can be dynamic using simple language itself
        return false;
    }

    @Override
    protected Expression createExpression(Language language, String exp) {
        return language.createExpression(exp, createProperties());
    }

    @Override
    protected Predicate createPredicate(Language language, String exp) {
        return language.createPredicate(exp, createProperties());
    }

}

==> apache-camel-4.18.0-src.zip: apache-camel-4.18.0/core/camel-core-reifier/src/main/java/org/apache/camel/reifier/language/CSimpleExpressionReifier.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.reifier.language;

import org.apache.camel.CamelContext;
import org.apache.camel.model.language.CSimpleExpression;
import org.apache.camel.model.language.ExpressionDefinition;

public class CSimpleExpressionReifier extends TypedExpressionReifier<CSimpleExpression> {

    public CSimpleExpressionReifier(CamelContext camelContext, ExpressionDefinition definition) {
        super(camelContext, definition);
    }

    @Override
    public boolean isResolveOptionalExternalScriptEnabled() {
        // csimple language will handle to resolve external scripts as they can be dynamic using simple language itself
        return false;
    }

    @Override
    protected Object[] createProperties() {
        Object[] properties = new Object[4];
        properties[0] = asResultType();
        properties[1] = parseBoolean(definition.getTrim());
        properties[2] = parseBoolean(definition.getPretty());
        properties[3] = parseBoolean(definition.getTrimResult());
        return properties;
    }

}
